import { ChecksumAlgorithm } from "./constants";
/**
 * Returns the priority array of algorithm to use to verify checksum and names
 * to be used as a key in the response header.
 */
export declare const getChecksumAlgorithmListForResponse: (responseAlgorithms?: string[]) => ChecksumAlgorithm[];
