import { LoadedConfigSelectors } from "@smithy/node-config-provider";
import { RequestChecksumCalculation } from "./constants";
/**
 * @internal
 */
export declare const ENV_REQUEST_CHECKSUM_CALCULATION = "AWS_REQUEST_CHECKSUM_CALCULATION";
/**
 * @internal
 */
export declare const CONFIG_REQUEST_CHECKSUM_CALCULATION = "request_checksum_calculation";
/**
 * @internal
 */
export declare const NODE_REQUEST_CHECKSUM_CALCULATION_CONFIG_OPTIONS: LoadedConfigSelectors<RequestChecksumCalculation>;
