import { ChecksumConstructor } from "@smithy/types";
/**
 * @internal
 *
 * \@aws-sdk/crc64-nvme-crt will install the constructor in this
 * container if it is installed.
 *
 * This avoids a runtime-require being interpreted statically by bundlers.
 *
 */
export declare const crc64NvmeCrtContainer: {
    CrtCrc64Nvme: null | ChecksumConstructor;
};
