import { ChecksumConstructor, HashConstructor } from "@smithy/types";
/**
 * A function that, given a hash constructor and a string, calculates the hash of the string.
 */
export declare const stringHasher: (checksumAlgorithmFn: ChecksumConstructor | HashConstructor, body: any) => Promise<Uint8Array<ArrayBufferLike>>;
