import { ChecksumAlgorithm } from "./constants";
/**
 * List of algorithms supported by client.
 */
export declare const CLIENT_SUPPORTED_ALGORITHMS: ChecksumAlgorithm[];
/**
 * Priority order for validating checksum algorithm. A faster algorithm has higher priority.
 */
export declare const PRIORITY_ORDER_ALGORITHMS: ChecksumAlgorithm[];
