import { HeaderBag } from "@smithy/types";
/**
 * Returns true if header with headerPrefix is present in headers.
 * Comparisons are case-insensitive.
 */
export declare const hasHeaderWithPrefix: (headerPrefix: string, headers: HeaderBag) => boolean;
