import { ChecksumAlgorithm } from "./constants";
/**
 * Returns location (header/trailer) name to use to populate checksum in.
 */
export declare const getChecksumLocationName: (algorithm: ChecksumAlgorithm) => string;
