"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCrc32ChecksumAlgorithmFunction = void 0;
const crc32_1 = require("@aws-crypto/crc32");
const getCrc32ChecksumAlgorithmFunction = () => crc32_1.AwsCrc32;
exports.getCrc32ChecksumAlgorithmFunction = getCrc32ChecksumAlgorithmFunction;
