import { ChecksumConstructor, HashConstructor } from "@smithy/types";
export declare const stringHasher: (
  checksumAlgorithmFn: ChecksumConstructor | HashConstructor,
  body: any
) => Promise<Uint8Array<ArrayBufferLike>>;
