import { LoadedConfigSelectors } from "@smithy/node-config-provider";
import { ResponseChecksumValidation } from "./constants";
/**
 * @internal
 */
export declare const ENV_RESPONSE_CHECKSUM_VALIDATION = "AWS_RESPONSE_CHECKSUM_VALIDATION";
/**
 * @internal
 */
export declare const CONFIG_RESPONSE_CHECKSUM_VALIDATION = "response_checksum_validation";
/**
 * @internal
 */
export declare const NODE_RESPONSE_CHECKSUM_VALIDATION_CONFIG_OPTIONS: LoadedConfigSelectors<ResponseChecksumValidation>;
